@@ -1,6 +1,6 @@
 package rig::engine::base;
 BEGIN {
-  $rig::engine::base::VERSION = '0.01_04';
+  $rig::engine::base::VERSION = '0.02';
 }
 use strict;
 use warnings;
@@ -35,11 +35,9 @@ sub import {
     for my $module ( @module_list ) {
         no strict 'refs';
         my $name = $module->{name};
-        my $direct_import = 0;
-        if( $name =~ /^\+(.+)$/ ) {
-            $name = $1;
-            $direct_import = 1;
-        }
+        my $direct_import = do {
+            $name =~ /^\+(.+)$/ and $name=$1;
+        };
         my $version = $module->{version};
         my $optional = $module->{optional};
         my @module_args = ref $module->{args} eq 'ARRAY' ? @{$module->{args}} : ();
@@ -49,13 +47,13 @@ sub import {
         #print " --require $name (version=$version, optional=$optional)\n";
         eval "require $name" or do {
             $optional and next;
-            confess "rig: $name: $@";
+            carp "rig: $name: $@";
         };
         $self->_check_versions( $name, $version );
 
         my $can_import = defined &{$name.'::import'};
         # some modules you just can't reach:
-        if( !$can_import && $name->isa("Exporter") ) {
+        if( !$can_import ) {
             my $module_args_str = "'".join(q{','}, @module_args)."'"
                 if @module_args > 0;
             #print "   use $name $module_args_str\n";
@@ -356,7 +354,7 @@ rig::engine::base - Default engine for rig
 
 =head1 VERSION
 
-version 0.01_04
+version 0.02
 
 =head1 DESCRIPTION
 
